# mvbook

[![Release](https://github.com/jncraton/mvbook/actions/workflows/release.yml/badge.svg)](https://github.com/jncraton/mvbook/actions/workflows/release.yml)
[![pypi](https://github.com/jncraton/mvbook/actions/workflows/pypi.yml/badge.svg)](https://github.com/jncraton/mvbook/actions/workflows/pypi.yml)
[![Test](https://github.com/jncraton/mvbook/actions/workflows/test.yml/badge.svg)](https://github.com/jncraton/mvbook/actions/workflows/test.yml)
[![Lint](https://github.com/jncraton/mvbook/actions/workflows/lint.yml/badge.svg)](https://github.com/jncraton/mvbook/actions/workflows/lint.yml)

A small CLI to rename ebook files using Open Library metadata.

